#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-6GzsJpeCNA19w7kGce2hUX
key:                  postgrest-10.1.0-6GzsJpeCNA19w7kGce2hUX
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  d99280c7e764fc1cb3279b9d1e90ea2a
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-6GzsJpeCNA19w7kGce2hUX
depends:
    HTTP-4000.5.0-9GzGZ9HPLLhLONhXAoMTHF
    Ranged-sets-0.5.0-Fc6VKPkLQpTGChkFKuxloS
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    auto-update-0.1.6-9ZLoXqLZYQc6XJHVsuhZwh base-4.18.2.1
    base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3KPQ2ag2hyl5eroFFm5hRO
    cassava-0.5.4.1-BmohHwtb7uE93FFOI4JzTr
    configurator-pg-0.2.11-BDXi0IpffXuAQwQQB1tvpW containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-Aqi73NSaKOtBrj9sY73cl2
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-EgLg8PGwkExLk8aWhNikVq
    hasql-dynamic-statements-0.3.1.2-JlKtFJRmkKf7vxrdN5L7jw
    hasql-notifications-0.2.0.5-38QnBSw1oKVAbhpitmQEDp
    hasql-pool-0.8.0.2-EH544jmXdM677mFjF2tqnI
    hasql-transaction-1.0.1.2-8Waabu1D4oXrOT9rghCRq
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    insert-ordered-containers-0.2.5.3-cEV8jcm434F1TrPXjRwZR
    interpolatedstring-perl6-1.0.2-LppvJzSbJoZGmVQBk9qaNJ
    jose-0.10.0.1-5fjmsgZrCJ0JbbiwYwxVuP
    lens-5.3.5-60ILU9p4A3b30ZI7X5UwGa
    lens-aeson-1.2.3-Jkk8BlEQrHO67qK5f0qNtX mtl-2.3.1
    network-3.1.4.0-5wCX3hTprFv2vYcKA8r7kN
    network-uri-2.6.4.2-CsSn6pfoiNDqvqEIqKYSC
    optparse-applicative-0.18.1.0-6cREMRvcEOW6x5IeiCw6lt
    parsec-3.1.16.1 protolude-0.3.5-1wMfsC51Qex1dCrsWKFJ8Q
    regex-tdfa-1.3.2.5-GDcLEW3RNnhJam1iRhMaaH
    retry-0.9.3.1-7lBe6F8shN37VbjsRaRE53
    scientific-0.3.8.1-3SFYxv3bn8iY0w5N4dHFv
    swagger2-2.8.10-9Ikqa6gDGtBd5NQR5XRwV text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    vault-0.3.1.6-DBdbo6YM08YBBhh2vxlC07
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV
    wai-3.2.4-9U7mEZmQi9i5eOM7qE7ocW
    wai-cors-0.2.7-8fM0tEix6Hg2ymnfxXmnZd
    wai-extra-3.1.18-2SRGw9VzmnN6HNHOttXNHx
    wai-logger-2.5.0-BZ17DVCfXUmDBjwy8dRpWa
    warp-3.4.0-LIglPs87CdaJSo2i9x0lm4

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

